@@ -13,5 +13,11 @@ from mordl.upos_tagger import UposTagger
 from mordl.feat_tagger import FeatTagger
 from mordl.feats_tagger import FeatsJointTagger as FeatsTagger
 from mordl.lemma_tagger import LemmaTagger
+from mordl.deprel_tagger import DeprelTagger, DeprelSeqTagger
 from mordl.ne_tagger import NeTagger
 from mordl.base_tagger import conll18_ud_eval
+
+save_conllu = UposTagger.save_conllu
+load_conllu = UposTagger.load_conllu
+load_word_embeddings = WordEmbeddings.load
+remove_rare_feats = UposTagger.remove_rare_feats
