@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# MorDL project: NE tagger
+# MorDL project: MISC:NE tagger
 #
 # Copyright (C) 2020-present by Sergei Ternovykh, Anastasiya Nikiforova
 # License: BSD, see LICENSE for details
@@ -25,6 +25,15 @@ class NeTagger(FeatTagger):
     * `feats_prune_coef=0` means "do not use feats";
     * `feats_prune_coef=None` means "use all feats";
     * default `feats_prune_coef=6`.
+
+    **embs**: `dict` with paths to the embeddings file as keys and
+    corresponding embeddings models as values. If tagger needs to load any
+    embeddings model, firstly, model is looked up it in that `dict`.
+
+    During init, **embs** is copied to the `emb` attribute of the creating
+    object, and this attribute may be used further to share already loaded
+    embeddings with another taggers.
     """
-    def __init__(self, feats_prune_coef=6):
-        super().__init__('MISC:NE', feats_prune_coef=feats_prune_coef)
+    def __init__(self, feats_prune_coef=6, embs=None):
+        super().__init__('MISC:NE', feats_prune_coef=feats_prune_coef,
+                         embs=None)
